# Generated by Django 2.2.20 on 2022-01-21 09:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mpesa', '0006_auto_20220108_1033'),
    ]

    operations = [
        migrations.RenameField(
            model_name='paymenttransaction',
            old_name='checkoutRequestID',
            new_name='checkout_request_id',
        ),
        migrations.RenameField(
            model_name='paymenttransaction',
            old_name='isFinished',
            new_name='is_finished',
        ),
        migrations.RenameField(
            model_name='paymenttransaction',
            old_name='isSuccessFull',
            new_name='is_successful',
        ),
    ]
