# Generated by Django 2.2.5 on 2020-08-09 16:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mpesa', '0003_paymenttransaction_order_id'),
    ]

    operations = [
        migrations.RenameField(
            model_name='wallet',
            old_name='uid',
            new_name='uuid',
        ),
    ]
